==> classpath_0.12.orig.tar.gz: classpath-0.12/java/rmi/server/RemoteRef.java <==
/* RemoteRef.java --
   Copyright (c) 1996, 1997, 1998, 1999, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.rmi.server;

import java.io.Externalizable;
import java.io.ObjectOutput;
import java.lang.reflect.Method;
import java.rmi.Remote;
import java.rmi.RemoteException;

public interface RemoteRef extends Externalizable
{
  long serialVersionUID = 0;
  
  String packagePrefix = "gnu.java.rmi.server";

  /**
   * @deprecated
   */
  void invoke (RemoteCall call) throws Exception;
  
  Object invoke (Remote obj, Method method, Object[] params, long opnum)
    throws Exception;
  
  /**
   * @deprecated
   */
  RemoteCall newCall (RemoteObject obj, Operation[] op, int opnum, long hash)
    throws RemoteException;

  /**
   * @deprecated
   */
  void done (RemoteCall call) throws RemoteException;
  
  boolean remoteEquals (RemoteRef ref);
  
  int remoteHashCode();
  
  String getRefClass (ObjectOutput out);
  
  String remoteToString();
}

==> classpath-0.18.tar.gz: classpath-0.18/java/rmi/server/RemoteRef.java <==
/* RemoteRef.java --
   Copyright (c) 1996, 1997, 1998, 1999, 2004  Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */


package java.rmi.server;

import java.io.Externalizable;
import java.io.ObjectOutput;
import java.lang.reflect.Method;
import java.rmi.Remote;
import java.rmi.RemoteException;

public interface RemoteRef extends Externalizable
{
  long serialVersionUID = 3632638527362204081L;
  
  String packagePrefix = "gnu.java.rmi.server";

  /**
   * @deprecated
   */
  void invoke (RemoteCall call) throws Exception;
  
  Object invoke (Remote obj, Method method, Object[] params, long opnum)
    throws Exception;
  
  /**
   * @deprecated
   */
  RemoteCall newCall (RemoteObject obj, Operation[] op, int opnum, long hash)
    throws RemoteException;

  /**
   * @deprecated
   */
  void done (RemoteCall call) throws RemoteException;
  
  boolean remoteEquals (RemoteRef ref);
  
  int remoteHashCode();
  
  String getRefClass (ObjectOutput out);
  
  String remoteToString();
}
